#!/usr/bin/python
# All Rights Reserved. Copyright (c) 2018, Hitachi, Ltd.       #
# Licensed Material of Hitachi, Ltd.                           #
# Reproduction, use, modification or disclosure otherwise than #
# permitted in the License Agreement is strictly prohibited.   #

class HelpOption(Exception):
    pass

class NoExecution(Exception):
    pass

class OptionError(Exception):
    pass

class BaseError(Exception):
    def __init__(self, reason, code=None):
        self.reason = reason.strip()
        self.code = code

    def __str__(self):
        if self.code is None:
            return "%s" % self.reason
        else:
            return "%s (code=%s)" % (self.reason, self.code)

class ParameterError(BaseError):
    pass

class ConfigurationError(BaseError):
    pass

class ConnectionError(BaseError):
    def __str__(self):
        if self.code == 255:
            return "SSH connection error. (%s)" % self.reason
        elif self.code == 5:
            return "Proxy unresolved. (%s)" % self.reason
        elif self.code == 6:
            return "Host unresolved. (%s)" % self.reason
        elif self.code == 7:
            return "Connection failure. (%s)" % self.reason
        elif self.code == 28:
            return "Connection timeout. (%s)" % self.reason
        elif self.code == 35:
            return "SSL connection failure. (%s)" % self.reason
        elif self.code == 37:
            return "Local file access failure. (%s)" % self.reason
        elif self.code == 52:
            return "No reply. (%s)" % self.reason
        elif self.code == 55:
            return "Data sending failure. (%s)" % self.reason
        else:
            return "Other connection error. (code=%s, reason=%s)" % (self.code, self.reason)

class OperationError(BaseError):
    def __str__(self):
        if self.code == 401:
            return "Authentication failure. (%s)" % self.reason
        elif self.code == 403:
            return "Permission failure or protocol mismatch (http vs https). (%s)" % self.reason
        elif self.code == 404:
            return "An expected resource is not found. (%s)" % self.reason
        elif self.code == 503:
            return "Temporary server failure. (%s)" % self.reason
        else:
            return "Other operation error. (code=%s, reason=%s)" % (self.code, self.reason)
